@@ -3,6 +3,6 @@ cat > $1/demos/Makefile.am <<EOF
 noinst_PROGRAMS = demo
 
 demo_SOURCES = demo.c
-demo_CPPFLAGS = \$(DEPS_CFLAGS) -I\$(top_builddir)/src
+demo_CPPFLAGS = \$(DEPS_CFLAGS) -I\$(top_srcdir)/src
 demo_LDADD = \$(DEPS_LIBS) -L\$(top_builddir)/src -l${1#lib}
 EOF
