@@ -1,11 +1,12 @@
 #!/usr/bin/env bash
+TRPROGRAM=$(printf $1 | tr - _)
 cat > $1/src/Makefile.am <<EOF
 bin_PROGRAMS = $1
-${1}_SOURCES = main.c \\
+${TRPROGRAM}_SOURCES = main.c \\
        g-hello-world.h g-hello-world-private.h g-hello-world.c g-hello-world.gob \\
        \$(BUILT_SOURCES)
-${1}_CPPFLAGS = \$(DEPS_CFLAGS)
-${1}_LDADD = \$(DEPS_LIBS)
+${TRPROGRAM}_CPPFLAGS = \$(DEPS_CFLAGS)
+${TRPROGRAM}_LDADD = \$(DEPS_LIBS)
 BUILT_SOURCES = g-hello-world.gob.stamp
 
 MAINTAINERCLEANFILES = \$(BUILT_SOURCES)
